import { Component, ElementRef, Input, ViewChild, NgModule, EventEmitter, Output, HostBinding } from '@angular/core';
import { CommonModule } from '@angular/common';
import { AlluvialChart, AreaChart, StackedAreaChart, SimpleBarChart, GroupedBarChart, StackedBarChart, BoxplotChart, BubbleChart, BulletChart, DonutChart, GaugeChart, HistogramChart, LineChart, LollipopChart, PieChart, ScatterChart, MeterChart, RadarChart, ComboChart, TreeChart, TreemapChart, CirclePackChart, WordCloudChart, HeatmapChart, EXPERIMENTAL_ChoroplethChart } from '@carbon/charts';
import { buildStraightPathString } from '@carbon/charts/components/diagrams/buildPaths';
import { arrowLeft, arrowRight, circle, diamond, square, tee } from '@carbon/charts/components/diagrams/markerDefinitions';

/**
 * @fileoverview added by tsickle
 * Generated from: base-chart.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `BaseChart` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class BaseChart {
    /**
     * @param {?} elementRef
     */
    constructor(elementRef) {
        this.elementRef = elementRef;
    }
    /**
     * Data passed to charts library for displaying
     * @param {?} newData
     * @return {?}
     */
    set data(newData) {
        // If data already exists, that means the chart has been initialized
        /** @type {?} */
        const dataExistsAlready = this._data !== null && this._data !== undefined;
        this._data = newData;
        if (dataExistsAlready) {
            this.chart.model.setData(newData);
        }
    }
    /**
     * @return {?}
     */
    get data() {
        return this._data;
    }
    /**
     * Options passed to charts library
     * @param {?} newOptions
     * @return {?}
     */
    set options(newOptions) {
        // If data already exists, that means the chart has been initialized
        /** @type {?} */
        const optionsExistAlready = this._options !== null && this._options !== undefined;
        this._options = newOptions;
        if (optionsExistAlready) {
            this.chart.model.setOptions(newOptions);
        }
    }
    /**
     * @return {?}
     */
    get options() {
        return this._options;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        // Width prop is mandatory for the wrappers
        if (this.width) {
            this.options.width = this.width;
        }
        // Height prop is mandatory for the wrappers
        if (this.height) {
            this.options.height = this.height;
        }
    }
    /**
     * Runs after view init to create a chart, attach it to `chartRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        console.log("You need to implement your own `ngAfterViewInit()` function");
    }
}
BaseChart.decorators = [
    { type: Component, args: [{
                selector: "ibm-base-chart",
                template: ``
            }] }
];
/** @nocollapse */
BaseChart.ctorParameters = () => [
    { type: ElementRef }
];
BaseChart.propDecorators = {
    data: [{ type: Input }],
    options: [{ type: Input }],
    width: [{ type: Input }],
    height: [{ type: Input }],
    chartRef: [{ type: ViewChild, args: ["nChart",] }]
};
if (false) {
    /**
     * Chart width
     * @type {?}
     */
    BaseChart.prototype.width;
    /**
     * Chart height
     * @type {?}
     */
    BaseChart.prototype.height;
    /**
     * Chart container element ref
     * @type {?}
     */
    BaseChart.prototype.chartRef;
    /**
     * Chart object instance
     *
     * You can use this to do whatever you would normally do with a chart if you used
     * charts library directly.
     * @type {?}
     */
    BaseChart.prototype.chart;
    /**
     * @type {?}
     * @private
     */
    BaseChart.prototype._data;
    /**
     * @type {?}
     * @private
     */
    BaseChart.prototype._options;
    /**
     * @type {?}
     * @protected
     */
    BaseChart.prototype.elementRef;
}

/**
 * @fileoverview added by tsickle
 * Generated from: alluvial-chart.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `Alluvial` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class AlluvialChartComponent extends BaseChart {
    /**
     * Runs after view init to create a chart, attach it to `elementRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        this.chart = new AlluvialChart(this.elementRef.nativeElement, {
            data: this.data,
            options: this.options
        });
        Object.assign(this, this.chart);
    }
}
AlluvialChartComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-alluvial-chart",
                template: ``
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: area-chart.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `AreaChart` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class AreaChartComponent extends BaseChart {
    /**
     * Runs after view init to create a chart, attach it to `chartRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        this.chart = new AreaChart(this.chartRef.nativeElement, {
            data: this.data,
            options: this.options
        });
        Object.assign(this, this.chart);
    }
}
AreaChartComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-area-chart",
                template: `
		<div #nChart class="ibm-chart-container">
		</div>
	`
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: area-chart-stacked.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `StackedAreaChart` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class StackedAreaChartComponent extends BaseChart {
    /**
     * Runs after view init to create a chart, attach it to `elementRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        this.chart = new StackedAreaChart(this.elementRef.nativeElement, {
            data: this.data,
            options: this.options
        });
        Object.assign(this, this.chart);
    }
}
StackedAreaChartComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-stacked-area-chart",
                template: ``
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: bar-chart-simple.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `SimpleBarChart` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class SimpleBarChartComponent extends BaseChart {
    /**
     * Runs after view init to create a chart, attach it to `elementRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        this.chart = new SimpleBarChart(this.elementRef.nativeElement, {
            data: this.data,
            options: this.options
        });
        Object.assign(this, this.chart);
    }
}
SimpleBarChartComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-simple-bar-chart",
                template: ``
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: bar-chart-grouped.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `GroupedBarChart` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class GroupedBarChartComponent extends BaseChart {
    /**
     * Runs after view init to create a chart, attach it to `elementRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        this.chart = new GroupedBarChart(this.elementRef.nativeElement, {
            data: this.data,
            options: this.options
        });
        Object.assign(this, this.chart);
    }
}
GroupedBarChartComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-grouped-bar-chart",
                template: ``
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: bar-chart-stacked.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `StackedBarChart` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class StackedBarChartComponent extends BaseChart {
    /**
     * Runs after view init to create a chart, attach it to `elementRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        this.chart = new StackedBarChart(this.elementRef.nativeElement, {
            data: this.data,
            options: this.options
        });
        Object.assign(this, this.chart);
    }
}
StackedBarChartComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-stacked-bar-chart",
                template: ``
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: boxplot-chart.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `BoxplotChart` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class BoxplotChartComponent extends BaseChart {
    /**
     * Runs after view init to create a chart, attach it to `elementRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        this.chart = new BoxplotChart(this.elementRef.nativeElement, {
            data: this.data,
            options: this.options
        });
        Object.assign(this, this.chart);
    }
}
BoxplotChartComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-boxplot-chart",
                template: ``
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: bubble-chart.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `BubbleChart` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class BubbleChartComponent extends BaseChart {
    /**
     * Runs after view init to create a chart, attach it to `elementRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        this.chart = new BubbleChart(this.elementRef.nativeElement, {
            data: this.data,
            options: this.options
        });
        Object.assign(this, this.chart);
    }
}
BubbleChartComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-bubble-chart",
                template: ``
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: bullet-chart.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `BulletChart` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class BulletChartComponent extends BaseChart {
    /**
     * Runs after view init to create a chart, attach it to `elementRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        this.chart = new BulletChart(this.elementRef.nativeElement, {
            data: this.data,
            options: this.options
        });
        Object.assign(this, this.chart);
    }
}
BulletChartComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-bullet-chart",
                template: ``
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: donut-chart.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `DonutChart` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class DonutChartComponent extends BaseChart {
    /**
     * Runs after view init to create a chart, attach it to `elementRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        this.chart = new DonutChart(this.elementRef.nativeElement, {
            data: this.data,
            options: this.options
        });
        Object.assign(this, this.chart);
    }
}
DonutChartComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-donut-chart",
                template: ``
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: gauge-chart.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `GaugeChart` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class GaugeChartComponent extends BaseChart {
    /**
     * Runs after view init to create a chart, attach it to `elementRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        this.chart = new GaugeChart(this.elementRef.nativeElement, {
            data: this.data,
            options: this.options
        });
        Object.assign(this, this.chart);
    }
}
GaugeChartComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-gauge-chart",
                template: ``
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: histogram-chart.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `HistogramChart` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class HistogramChartComponent extends BaseChart {
    /**
     * Runs after view init to create a chart, attach it to `elementRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        this.chart = new HistogramChart(this.elementRef.nativeElement, {
            data: this.data,
            options: this.options
        });
        Object.assign(this, this.chart);
    }
}
HistogramChartComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-histogram-chart",
                template: ``
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: line-chart.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `LineChart` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class LineChartComponent extends BaseChart {
    /**
     * Runs after view init to create a chart, attach it to `elementRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        this.chart = new LineChart(this.elementRef.nativeElement, {
            data: this.data,
            options: this.options
        });
        Object.assign(this, this.chart);
    }
}
LineChartComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-line-chart",
                template: ``
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lollipop-chart.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `LollipopChart` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class LollipopChartComponent extends BaseChart {
    /**
     * Runs after view init to create a chart, attach it to `elementRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        this.chart = new LollipopChart(this.elementRef.nativeElement, {
            data: this.data,
            options: this.options
        });
        Object.assign(this, this.chart);
    }
}
LollipopChartComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-lollipop-chart",
                template: ``
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: pie-chart.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `PieChart` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class PieChartComponent extends BaseChart {
    /**
     * Runs after view init to create a chart, attach it to `elementRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        this.chart = new PieChart(this.elementRef.nativeElement, {
            data: this.data,
            options: this.options
        });
        Object.assign(this, this.chart);
    }
}
PieChartComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-pie-chart",
                template: ``
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: scatter-chart.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `ScatterChart` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class ScatterChartComponent extends BaseChart {
    /**
     * Runs after view init to create a chart, attach it to `elementRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        this.chart = new ScatterChart(this.elementRef.nativeElement, {
            data: this.data,
            options: this.options
        });
        Object.assign(this, this.chart);
    }
}
ScatterChartComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-scatter-chart",
                template: ``
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: meter-chart.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `MeterChart` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class MeterChartComponent extends BaseChart {
    /**
     * Runs after view init to create a chart, attach it to `elementRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        this.chart = new MeterChart(this.elementRef.nativeElement, {
            data: this.data,
            options: this.options
        });
        Object.assign(this, this.chart);
    }
}
MeterChartComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-meter-chart",
                template: ``
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: radar-chart.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `RadarChart` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class RadarChartComponent extends BaseChart {
    /**
     * Runs after view init to create a chart, attach it to `elementRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        this.chart = new RadarChart(this.elementRef.nativeElement, {
            data: this.data,
            options: this.options
        });
        Object.assign(this, this.chart);
    }
}
RadarChartComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-radar-chart",
                template: ``
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: combo-chart.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `ComboChart` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class ComboChartComponent extends BaseChart {
    /**
     * Runs after view init to create a chart, attach it to `elementRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        this.chart = new ComboChart(this.elementRef.nativeElement, {
            data: this.data,
            options: this.options
        });
        Object.assign(this, this.chart);
    }
}
ComboChartComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-combo-chart",
                template: ``
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: tree-chart.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `TreeChart` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class TreeChartComponent extends BaseChart {
    /**
     * Runs after view init to create a chart, attach it to `elementRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        this.chart = new TreeChart(this.elementRef.nativeElement, {
            data: this.data,
            options: this.options
        });
        Object.assign(this, this.chart);
    }
}
TreeChartComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-tree-chart",
                template: ``
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: treemap-chart.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `TreemapChart` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class TreemapChartComponent extends BaseChart {
    /**
     * Runs after view init to create a chart, attach it to `elementRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        this.chart = new TreemapChart(this.elementRef.nativeElement, {
            data: this.data,
            options: this.options
        });
        Object.assign(this, this.chart);
    }
}
TreemapChartComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-treemap-chart",
                template: ``
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: circle-pack-chart.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `BubbleChart` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class CirclePackChartComponent extends BaseChart {
    /**
     * Runs after view init to create a chart, attach it to `elementRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        this.chart = new CirclePackChart(this.elementRef.nativeElement, {
            data: this.data,
            options: this.options
        });
        Object.assign(this, this.chart);
    }
}
CirclePackChartComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-circle-pack-chart",
                template: ``
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: wordcloud-chart.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `WordCloudChart` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class WordCloudChartComponent extends BaseChart {
    /**
     * Runs after view init to create a chart, attach it to `elementRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        this.chart = new WordCloudChart(this.elementRef.nativeElement, {
            data: this.data,
            options: this.options
        });
        Object.assign(this, this.chart);
    }
}
WordCloudChartComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-wordcloud-chart",
                template: ``
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: heatmap-chart.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `Heatmap` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class HeatmapChartComponent extends BaseChart {
    /**
     * Runs after view init to create a chart, attach it to `elementRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        this.chart = new HeatmapChart(this.elementRef.nativeElement, {
            data: this.data,
            options: this.options
        });
        Object.assign(this, this.chart);
    }
}
HeatmapChartComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-heatmap-chart",
                template: ``
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: choropleth.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Wrapper around `Choropleth` in carbon charts library
 *
 * Most functions just call their equivalent from the chart library.
 */
class EXPERIMENTAL_ChoroplethChartComponent extends BaseChart {
    /**
     * Runs after view init to create a chart, attach it to `elementRef` and draw it.
     * @return {?}
     */
    ngAfterViewInit() {
        this.chart = new EXPERIMENTAL_ChoroplethChart(this.elementRef.nativeElement, {
            data: this.data,
            options: this.options
        });
        Object.assign(this, this.chart);
    }
}
EXPERIMENTAL_ChoroplethChartComponent.decorators = [
    { type: Component, args: [{
                selector: "EXPERIMENTAL-ibm-choropleth-chart",
                template: ``
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: charts.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ChartsModule {
}
ChartsModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [
                    BaseChart,
                    AlluvialChartComponent,
                    AreaChartComponent,
                    EXPERIMENTAL_ChoroplethChartComponent,
                    StackedAreaChartComponent,
                    SimpleBarChartComponent,
                    GroupedBarChartComponent,
                    StackedBarChartComponent,
                    BoxplotChartComponent,
                    BubbleChartComponent,
                    BulletChartComponent,
                    DonutChartComponent,
                    GaugeChartComponent,
                    HeatmapChartComponent,
                    HistogramChartComponent,
                    LineChartComponent,
                    LollipopChartComponent,
                    PieChartComponent,
                    ScatterChartComponent,
                    MeterChartComponent,
                    RadarChartComponent,
                    ComboChartComponent,
                    TreeChartComponent,
                    TreemapChartComponent,
                    CirclePackChartComponent,
                    WordCloudChartComponent,
                ],
                exports: [
                    BaseChart,
                    AlluvialChartComponent,
                    AreaChartComponent,
                    EXPERIMENTAL_ChoroplethChartComponent,
                    StackedAreaChartComponent,
                    SimpleBarChartComponent,
                    GroupedBarChartComponent,
                    StackedBarChartComponent,
                    BoxplotChartComponent,
                    BubbleChartComponent,
                    BulletChartComponent,
                    DonutChartComponent,
                    GaugeChartComponent,
                    HeatmapChartComponent,
                    HistogramChartComponent,
                    LineChartComponent,
                    LollipopChartComponent,
                    PieChartComponent,
                    ScatterChartComponent,
                    MeterChartComponent,
                    RadarChartComponent,
                    ComboChartComponent,
                    TreeChartComponent,
                    TreemapChartComponent,
                    CirclePackChartComponent,
                    WordCloudChartComponent
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: diagrams/configs.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const carbonPrefix = 'cds';

/**
 * @fileoverview added by tsickle
 * Generated from: diagrams/card-node/card-node.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CardNodeComponent {
    constructor() {
        this.as = 'div';
        this.href = null;
        this.position = 'static';
        this.click = new EventEmitter();
        this.mouseEnter = new EventEmitter();
        this.mouseOver = new EventEmitter();
        this.mouseOut = new EventEmitter();
        this.mouseLeave = new EventEmitter();
        this.mouseMove = new EventEmitter();
        this.namespace = `${carbonPrefix}--cc--card-node`;
        this.component = 'div';
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.href) {
            this.component = 'a';
        }
        else {
            this.component = this.as;
        }
    }
}
CardNodeComponent.decorators = [
    { type: Component, args: [{
                selector: 'ibm-diagram-card-node',
                template: `
		<ng-container [ngSwitch]="component">
			<xhtml:div
				*ngSwitchCase="'div'"
				[ngClass]="[
					namespace,
					stacked ? namespace + '--stacked' : '',
					namespace + '--' + component
				]"
				[ngStyle]="{
					'border-color': color,
					position: position
				}"
				(mouseenter)="mouseEnter.emit($event)"
				(mouseover)="mouseOver.emit($event)"
				(mouseout)="mouseOut.emit($event)"
				(mouseleave)="mouseLeave.emit($event)"
				(mousemove)="mouseMove.emit($event)"
				tabindex="0"
			>
				<ng-container *ngTemplateOutlet="nodeTemplate"></ng-container>
			</xhtml:div>

			<xhtml:button
				*ngSwitchCase="'button'"
				[ngClass]="[
					namespace,
					stacked ? namespace + '--stacked' : '',
					namespace + '--' + component
				]"
				[ngStyle]="{
					'border-color': color,
					position: position
				}"
				(click)="click.emit($event)"
				(mouseenter)="mouseEnter.emit($event)"
				(mouseover)="mouseOver.emit($event)"
				(mouseout)="mouseOut.emit($event)"
				(mouseleave)="mouseLeave.emit($event)"
				(mousemove)="mouseMove.emit($event)"
				tabindex="0"
			>
				<ng-container *ngTemplateOutlet="nodeTemplate"></ng-container>
			</xhtml:button>

			<xhtml:a
				*ngSwitchCase="'a'"
				[ngClass]="[
					namespace,
					stacked ? namespace + '--stacked' : '',
					namespace + '--' + component
				]"
				[attr.href]="href"
				[ngStyle]="{ 'border-color': color, position: position }"
				(mouseenter)="mouseEnter.emit($event)"
				(mouseover)="mouseOver.emit($event)"
				(mouseout)="mouseOut.emit($event)"
				(mouseleave)="mouseLeave.emit($event)"
				(mousemove)="mouseMove.emit($event)"
				tabindex="0"
			>
				<ng-container *ngTemplateOutlet="nodeTemplate"></ng-container>
			</xhtml:a>
		</ng-container>
		<ng-template #nodeTemplate>
			<ng-content></ng-content>
		</ng-template>
	`
            }] }
];
CardNodeComponent.propDecorators = {
    as: [{ type: Input }],
    href: [{ type: Input }],
    color: [{ type: Input }],
    stacked: [{ type: Input }],
    position: [{ type: Input }],
    click: [{ type: Output }],
    mouseEnter: [{ type: Output }],
    mouseOver: [{ type: Output }],
    mouseOut: [{ type: Output }],
    mouseLeave: [{ type: Output }],
    mouseMove: [{ type: Output }]
};
if (false) {
    /** @type {?} */
    CardNodeComponent.prototype.as;
    /** @type {?} */
    CardNodeComponent.prototype.href;
    /** @type {?} */
    CardNodeComponent.prototype.color;
    /** @type {?} */
    CardNodeComponent.prototype.stacked;
    /** @type {?} */
    CardNodeComponent.prototype.position;
    /** @type {?} */
    CardNodeComponent.prototype.click;
    /** @type {?} */
    CardNodeComponent.prototype.mouseEnter;
    /** @type {?} */
    CardNodeComponent.prototype.mouseOver;
    /** @type {?} */
    CardNodeComponent.prototype.mouseOut;
    /** @type {?} */
    CardNodeComponent.prototype.mouseLeave;
    /** @type {?} */
    CardNodeComponent.prototype.mouseMove;
    /** @type {?} */
    CardNodeComponent.prototype.namespace;
    /** @type {?} */
    CardNodeComponent.prototype.component;
}

/**
 * @fileoverview added by tsickle
 * Generated from: diagrams/card-node/card-node-column.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CardNodeColumnComponent {
    constructor() {
        this.farsideColumn = false;
    }
    /**
     * @return {?}
     */
    get class() {
        /** @type {?} */
        const farsideClassName = this.farsideColumn
            ? `${carbonPrefix}--cc--card-node__column--farside`
            : '';
        return `${carbonPrefix}--cc--card-node__column ${farsideClassName}`;
    }
}
CardNodeColumnComponent.decorators = [
    { type: Component, args: [{
                selector: 'ibm-diagram-card-node-column',
                template: `
		<xhtml:div>
			<ng-content></ng-content>
		</xhtml:div>
	`
            }] }
];
CardNodeColumnComponent.propDecorators = {
    farsideColumn: [{ type: Input }],
    class: [{ type: HostBinding, args: ['class',] }]
};
if (false) {
    /** @type {?} */
    CardNodeColumnComponent.prototype.farsideColumn;
}

/**
 * @fileoverview added by tsickle
 * Generated from: diagrams/card-node/card-node-label.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CardNodeLabelComponent {
    constructor() {
        this.namespace = `${carbonPrefix}--cc--card-node__label`;
    }
}
CardNodeLabelComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-diagram-card-node-label",
                template: `
	<xhtml:label [ngClass]="namespace">
		<ng-content></ng-content>
	</xhtml:label>
	`
            }] }
];
if (false) {
    /** @type {?} */
    CardNodeLabelComponent.prototype.namespace;
}

/**
 * @fileoverview added by tsickle
 * Generated from: diagrams/card-node/card-node-subtitle.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CardNodeSubtitleComponent {
    constructor() {
        this.namespace = `${carbonPrefix}--cc--card-node__subtitle`;
    }
}
CardNodeSubtitleComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-diagram-card-node-subtitle",
                template: `
	<xhtml:div [ngClass]="namespace">
		<ng-content></ng-content>
	</xhtml:div>
	`
            }] }
];
if (false) {
    /** @type {?} */
    CardNodeSubtitleComponent.prototype.namespace;
}

/**
 * @fileoverview added by tsickle
 * Generated from: diagrams/card-node/card-node-title.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CardNodeTitleComponent {
    constructor() {
        this.namespace = `${carbonPrefix}--cc--card-node__title`;
    }
}
CardNodeTitleComponent.decorators = [
    { type: Component, args: [{
                selector: "ibm-diagram-card-node-title",
                template: `
	<xhtml:div [ngClass]="namespace">
		<ng-content></ng-content>
	</xhtml:div>
	`
            }] }
];
if (false) {
    /** @type {?} */
    CardNodeTitleComponent.prototype.namespace;
}

/**
 * @fileoverview added by tsickle
 * Generated from: diagrams/card-node/card-node.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CardNodeModule {
}
CardNodeModule.decorators = [
    { type: NgModule, args: [{
                declarations: [CardNodeComponent, CardNodeColumnComponent, CardNodeLabelComponent, CardNodeSubtitleComponent, CardNodeTitleComponent],
                exports: [CardNodeComponent, CardNodeColumnComponent, CardNodeLabelComponent, CardNodeSubtitleComponent, CardNodeTitleComponent],
                imports: [CommonModule]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: diagrams/edge/edge.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function Coordinates() { }
if (false) {
    /** @type {?} */
    Coordinates.prototype.x;
    /** @type {?} */
    Coordinates.prototype.y;
}
class EdgeComponent {
    constructor() {
        this.namespace = `${carbonPrefix}--cc--edge`;
        this.straight = buildStraightPathString;
    }
}
EdgeComponent.decorators = [
    { type: Component, args: [{
                selector: "[ibm-graph-edge]",
                template: `
	<svg:g [ngClass]="[namespace, variant ? namespace + '--' + variant : '']">
		<svg:path
			[ngClass]="namespace + '__container'"
			[attr.d]="path ? path : straight(source, target)"
		/>
		<svg:path
			[ngClass]="namespace + '__outer'"
			[attr.d]="path ? path : straight(source, target)"
		/>
		<svg:path
			[ngClass]="namespace + '__inner'"
			[attr.d]="path ? path : straight(source, target)"
			[ngStyle]="{'stroke': color}"
			[attr.marker-start]="markerStart ? 'url(#' + markerStart + ')' : ''"
			[attr.marker-end]="markerEnd ? 'url(#' + markerEnd + ')' : ''"
		/>
	</svg:g>
	`
            }] }
];
EdgeComponent.propDecorators = {
    color: [{ type: Input }],
    markerEnd: [{ type: Input }],
    markerStart: [{ type: Input }],
    source: [{ type: Input }],
    target: [{ type: Input }],
    variant: [{ type: Input }],
    path: [{ type: Input }]
};
if (false) {
    /** @type {?} */
    EdgeComponent.prototype.color;
    /** @type {?} */
    EdgeComponent.prototype.markerEnd;
    /** @type {?} */
    EdgeComponent.prototype.markerStart;
    /** @type {?} */
    EdgeComponent.prototype.source;
    /** @type {?} */
    EdgeComponent.prototype.target;
    /** @type {?} */
    EdgeComponent.prototype.variant;
    /** @type {?} */
    EdgeComponent.prototype.path;
    /** @type {?} */
    EdgeComponent.prototype.pathClasses;
    /** @type {?} */
    EdgeComponent.prototype.namespace;
    /** @type {?} */
    EdgeComponent.prototype.straight;
}

/**
 * @fileoverview added by tsickle
 * Generated from: diagrams/edge/edge.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class EdgeModule {
}
EdgeModule.decorators = [
    { type: NgModule, args: [{
                declarations: [EdgeComponent],
                exports: [EdgeComponent],
                imports: [CommonModule]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: diagrams/marker/marker.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const template = `
<svg:marker
	[ngClass]="namespace"
	[attr.markerHeight]="height"
	[attr.markerWidth]="width"
	[attr.orient]="orient"
	[attr.id]="id"
	[attr.refX]="refX"
	[attr.refY]="refY"
	markerUnits="userSpaceOnUse">
	<svg:path [attr.d]="d" [ngStyle]="{'fill': color}" ></svg:path>
</svg:marker>
`;
class MarkerComponent {
    constructor() {
        this.orient = "auto";
        this.position = "end";
        this.namespace = `${carbonPrefix}--cc--marker`;
        this.setAttributes = (/**
         * @param {?} __0
         * @return {?}
         */
        ({ d, id, height, width }) => {
            /** @type {?} */
            const xPos = (this.position === "end") ? (width / 2) + 0.5 : 0.5;
            /** @type {?} */
            const yPos = height / 2;
            this.d = this.d || d;
            this.id = this.id || id;
            this.height = this.height || height;
            this.width = this.width || width;
            this.refX = this.refX || xPos;
            this.refY = this.refY || yPos;
        });
    }
}
MarkerComponent.decorators = [
    { type: Component, args: [{
                selector: "[ibm-graph-marker]",
                template
            }] }
];
MarkerComponent.propDecorators = {
    d: [{ type: Input }],
    color: [{ type: Input }],
    id: [{ type: Input }],
    orient: [{ type: Input }],
    height: [{ type: Input }],
    width: [{ type: Input }],
    refX: [{ type: Input }],
    refY: [{ type: Input }],
    position: [{ type: Input }]
};
if (false) {
    /** @type {?} */
    MarkerComponent.prototype.d;
    /** @type {?} */
    MarkerComponent.prototype.color;
    /** @type {?} */
    MarkerComponent.prototype.id;
    /** @type {?} */
    MarkerComponent.prototype.orient;
    /** @type {?} */
    MarkerComponent.prototype.height;
    /** @type {?} */
    MarkerComponent.prototype.width;
    /** @type {?} */
    MarkerComponent.prototype.refX;
    /** @type {?} */
    MarkerComponent.prototype.refY;
    /** @type {?} */
    MarkerComponent.prototype.position;
    /** @type {?} */
    MarkerComponent.prototype.namespace;
    /** @type {?} */
    MarkerComponent.prototype.setAttributes;
}
class MarkerArrowLeftComponent extends MarkerComponent {
    /**
     * @return {?}
     */
    ngOnInit() { this.setAttributes(Object.assign({}, arrowLeft)); }
}
MarkerArrowLeftComponent.decorators = [
    { type: Component, args: [{ selector: "[ibm-graph-marker-arrow-left]", template }] }
];
class MarkerArrowRightComponent extends MarkerComponent {
    /**
     * @return {?}
     */
    ngOnInit() { this.setAttributes(Object.assign({}, arrowRight)); }
}
MarkerArrowRightComponent.decorators = [
    { type: Component, args: [{ selector: "[ibm-graph-marker-arrow-right]", template }] }
];
class MarkerShapeNodeComponent extends MarkerComponent {
    /**
     * @return {?}
     */
    ngOnInit() { this.setAttributes(Object.assign({}, circle)); }
}
MarkerShapeNodeComponent.decorators = [
    { type: Component, args: [{ selector: "[ibm-graph-marker-circle]", template }] }
];
class MarkerDiamondComponent extends MarkerComponent {
    /**
     * @return {?}
     */
    ngOnInit() { this.setAttributes(Object.assign({}, diamond)); }
}
MarkerDiamondComponent.decorators = [
    { type: Component, args: [{ selector: "[ibm-graph-marker-diamond]", template }] }
];
class MarkerSquareComponent extends MarkerComponent {
    /**
     * @return {?}
     */
    ngOnInit() { this.setAttributes(Object.assign({}, square)); }
}
MarkerSquareComponent.decorators = [
    { type: Component, args: [{ selector: "[ibm-graph-marker-square]", template }] }
];
class MarkerTeeComponent extends MarkerComponent {
    /**
     * @return {?}
     */
    ngOnInit() { this.setAttributes(Object.assign({}, tee)); }
}
MarkerTeeComponent.decorators = [
    { type: Component, args: [{ selector: "[ibm-graph-marker-tee]", template }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: diagrams/marker/marker.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MarkerModule {
}
MarkerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    MarkerComponent,
                    MarkerArrowLeftComponent,
                    MarkerArrowRightComponent,
                    MarkerShapeNodeComponent,
                    MarkerDiamondComponent,
                    MarkerSquareComponent,
                    MarkerTeeComponent
                ],
                exports: [
                    MarkerComponent,
                    MarkerArrowLeftComponent,
                    MarkerArrowRightComponent,
                    MarkerShapeNodeComponent,
                    MarkerDiamondComponent,
                    MarkerSquareComponent,
                    MarkerTeeComponent
                ],
                imports: [CommonModule]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: diagrams/shape-node/shape-node.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ShapeNodeComponent {
    constructor() {
        this.as = 'div';
        this.href = null;
        this.size = 48;
        this.shape = 'circle';
        this.position = 'fixed';
        this.bodyPosition = 'absolute';
        this.click = new EventEmitter();
        this.mouseEnter = new EventEmitter();
        this.mouseOver = new EventEmitter();
        this.mouseOut = new EventEmitter();
        this.mouseLeave = new EventEmitter();
        this.mouseMove = new EventEmitter();
        this.namespace = `${carbonPrefix}--cc--shape-node`;
        this.component = 'div';
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.href) {
            this.component = 'a';
        }
        else {
            this.component = this.as;
        }
    }
}
ShapeNodeComponent.decorators = [
    { type: Component, args: [{
                selector: 'ibm-diagram-shape-node',
                template: `
		<ng-container [ngSwitch]="component">
			<xhtml:div
				*ngSwitchCase="'div'"
				[ngClass]="[
					namespace,
					stacked ? namespace + '--stacked' : '',
					shape ? namespace + '--' + shape : '',
					namespace + '--' + component
				]"
				[ngStyle]="{
					'height.px': size,
					'width.px': size,
					position: position
				}"
				(mouseenter)="mouseEnter.emit($event)"
				(mouseover)="mouseOver.emit($event)"
				(mouseout)="mouseOut.emit($event)"
				(mouseleave)="mouseLeave.emit($event)"
				(mousemove)="mouseMove.emit($event)"
				tabindex="0"
			>
				<ng-container *ngTemplateOutlet="nodeTemplate"></ng-container>
			</xhtml:div>

			<xhtml:button
				*ngSwitchCase="'button'"
				[ngClass]="[
					namespace,
					stacked ? namespace + '--stacked' : '',
					shape ? namespace + '--' + shape : '',
					namespace + '--' + component
				]"
				[ngStyle]="{
					'height.px': size,
					'width.px': size,
					position: position
				}"
				(click)="click.emit($event)"
				(mouseenter)="mouseEnter.emit($event)"
				(mouseover)="mouseOver.emit($event)"
				(mouseout)="mouseOut.emit($event)"
				(mouseleave)="mouseLeave.emit($event)"
				(mousemove)="mouseMove.emit($event)"
				tabindex="0"
			>
				<ng-container *ngTemplateOutlet="nodeTemplate"></ng-container>
			</xhtml:button>

			<xhtml:a
				*ngSwitchCase="'a'"
				[ngClass]="[
					namespace,
					stacked ? namespace + '--stacked' : '',
					shape ? namespace + '--' + shape : '',
					namespace + '--' + component
				]"
				[attr.href]="href"
				[ngStyle]="{
					'height.px': size,
					'width.px': size,
					position: position
				}"
				(mouseenter)="mouseEnter.emit($event)"
				(mouseover)="mouseOver.emit($event)"
				(mouseout)="mouseOut.emit($event)"
				(mouseleave)="mouseLeave.emit($event)"
				(mousemove)="mouseMove.emit($event)"
				tabindex="0"
			>
				<ng-container *ngTemplateOutlet="nodeTemplate"></ng-container>
			</xhtml:a>
		</ng-container>

		<ng-template #nodeTemplate>
			<div *ngIf="renderIcon" attr.class="{{ namespace + '__icon' }}">
				<ng-container *ngTemplateOutlet="renderIcon"></ng-container>
			</div>
			<div
				attr.class="{{ namespace + '__body' }}"
				[ngStyle]="{ position: bodyPosition }"
			>
				<div attr.class="{{ namespace + '__title' }}">{{ title }}</div>
				<div attr.class="{{ namespace + '__subtitle' }}">
					{{ subtitle }}
				</div>
			</div>
		</ng-template>
	`
            }] }
];
ShapeNodeComponent.propDecorators = {
    as: [{ type: Input }],
    href: [{ type: Input }],
    renderIcon: [{ type: Input }],
    size: [{ type: Input }],
    stacked: [{ type: Input }],
    shape: [{ type: Input }],
    subtitle: [{ type: Input }],
    title: [{ type: Input }],
    position: [{ type: Input }],
    bodyPosition: [{ type: Input }],
    click: [{ type: Output }],
    mouseEnter: [{ type: Output }],
    mouseOver: [{ type: Output }],
    mouseOut: [{ type: Output }],
    mouseLeave: [{ type: Output }],
    mouseMove: [{ type: Output }]
};
if (false) {
    /** @type {?} */
    ShapeNodeComponent.prototype.as;
    /** @type {?} */
    ShapeNodeComponent.prototype.href;
    /** @type {?} */
    ShapeNodeComponent.prototype.renderIcon;
    /** @type {?} */
    ShapeNodeComponent.prototype.size;
    /** @type {?} */
    ShapeNodeComponent.prototype.stacked;
    /** @type {?} */
    ShapeNodeComponent.prototype.shape;
    /** @type {?} */
    ShapeNodeComponent.prototype.subtitle;
    /** @type {?} */
    ShapeNodeComponent.prototype.title;
    /** @type {?} */
    ShapeNodeComponent.prototype.position;
    /** @type {?} */
    ShapeNodeComponent.prototype.bodyPosition;
    /** @type {?} */
    ShapeNodeComponent.prototype.click;
    /** @type {?} */
    ShapeNodeComponent.prototype.mouseEnter;
    /** @type {?} */
    ShapeNodeComponent.prototype.mouseOver;
    /** @type {?} */
    ShapeNodeComponent.prototype.mouseOut;
    /** @type {?} */
    ShapeNodeComponent.prototype.mouseLeave;
    /** @type {?} */
    ShapeNodeComponent.prototype.mouseMove;
    /** @type {?} */
    ShapeNodeComponent.prototype.namespace;
    /** @type {?} */
    ShapeNodeComponent.prototype.component;
}

/**
 * @fileoverview added by tsickle
 * Generated from: diagrams/shape-node/shape-node.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ShapeNodeModule {
}
ShapeNodeModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ShapeNodeComponent],
                exports: [ShapeNodeComponent],
                imports: [CommonModule]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: carbon-charts-angular.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { AlluvialChartComponent, AreaChartComponent, BaseChart, BoxplotChartComponent, BubbleChartComponent, BulletChartComponent, CardNodeColumnComponent, CardNodeComponent, CardNodeLabelComponent, CardNodeModule, CardNodeSubtitleComponent, CardNodeTitleComponent, ChartsModule, CirclePackChartComponent, ComboChartComponent, DonutChartComponent, EdgeComponent, EdgeModule, GaugeChartComponent, GroupedBarChartComponent, HeatmapChartComponent, HistogramChartComponent, LineChartComponent, LollipopChartComponent, MarkerArrowLeftComponent, MarkerArrowRightComponent, MarkerComponent, MarkerDiamondComponent, MarkerModule, MarkerShapeNodeComponent, MarkerSquareComponent, MarkerTeeComponent, MeterChartComponent, PieChartComponent, RadarChartComponent, ScatterChartComponent, ShapeNodeComponent, ShapeNodeModule, SimpleBarChartComponent, StackedAreaChartComponent, StackedBarChartComponent, TreeChartComponent, TreemapChartComponent, WordCloudChartComponent, EXPERIMENTAL_ChoroplethChartComponent as ɵa };
//# sourceMappingURL=carbon-charts-angular.js.map
